'-------------------------------------------------------------------------------
' NAME   : Figlet.vbs
' AUTHOR : Prasad P. Khandekar
' DATE   : July 25, 2008
' VERSION: 1.0
' PURPOSE: Create ASCII art of supplied text.
'-------------------------------------------------------------------------------
Option Explicit
Const ForReading = 1
Dim objArgs, strText, strFont, gstrRootDir, gstrScript, objFiglet

Set objArgs = WScript.Arguments
If (objArgs.Length < 2) Then
    ShowHelp()
    WScript.Quit(1001)
End If

strText = objArgs.Named("text")
strFont = objArgs.Named("font")
gstrScript = WScript.ScriptName
gstrRootDir = WScript.ScriptFullName
gstrRootDir = Left(gstrRootDir, Instr(gstrRootDir, gstrScript) - 1)

Set objFiglet = New clsFiglet
Call objFiglet.Display(strText, gstrRootDir & "\fonts\" & strFont & ".flf")
WScript.Quit(0)

Class clsFiglet
    Dim strSignature
    Dim strHardBlank
    Dim intHeight
    Dim intBaseline
    Dim intMaxLen
    Dim intOldLayout
    Dim intCommentLines
    Dim intPrintDirection
    Dim intFullLayout
    Dim intCodeTagCount
    Dim fontData()

    Sub LoadFont(fontFile)
        Dim fso
        Dim hFile
        Dim cntr
        Dim arrTmp
        Dim strTmp
        Dim uBnd

        Set fso = WScript.CreateObject("Scripting.FileSystemObject")
        Set hFile = fso.OpenTextFile(fontFile, ForReading, False)
        cntr = 0
        ReDim fontData(4096)
        Do While Not hFile.AtEndOfStream
            fontData(cntr) = hFile.ReadLine
            cntr = cntr + 1
            If (cntr = UBound(fontData)) Then ReDim Preserve fontData(cntr + 100)
        Loop
        ReDim Preserve fontData(cntr)

        arrTmp = Split(fontData(0), " ",  -1)
        uBnd = UBound(arrTmp)
        strTmp = arrTmp(0)
        strSignature = Left(strTmp, Len(strTmp) - 1)
        strHardBlank = Right(strTmp,  1)
        intHeight = CInt(arrTmp(1))
        intBaseLine = CInt(arrTmp(2))
        intMaxLen = CInt(arrTmp(3))
        intOldLayout = CInt(arrTmp(4))
        intCommentLines = CInt(arrTmp(5))
        If (uBnd > 5) Then intPrintDirection = CInt(arrTmp(6))
        If (uBnd > 6) Then intFullLayout = CInt(arrTmp(7))
        If (uBnd > 7) Then intCodeTagCount = CInt(arrTmp(8))
        Erase arrTmp
        If (strSignature <> "flf2a") Then
            Err.Raise vbObjectError + 1000, "LoadFont", "Font " & fontFile & " is not a Figley font!"
        End If
    End Sub

    Function GetCharacter(char, intLine)
        Dim intAscii
        Dim intStart
        Dim strTmp
        
        intAscii= Asc(char)
        intStart = intCommentLines + ((intAscii - 32) * intHeight)
        strTmp = fontData(intStart + intLine)
        strTmp = Replace(strTmp, "@", "")
        strTmp = Replace(strTmp, strHardBlank, " ")
        GetCharacter = strTmp
    End Function

    Sub Display(strText, strFont)
        Dim idx
        Dim cntr
        Dim char

        Call LoadFont(strFont)
        For cntr = 1 To intHeight
            For idx = 1 To Len(strText)
                char = Mid(strText, idx, 1)
                WScript.StdOut.Write GetCharacter(char, cntr)
            Next
            WScript.StdOut.Write vbCrLf
        Next
    End Sub
End Class

Sub ShowHelp()
    WScript.Echo "Usage : "
    WScript.Echo ""
    WScript.Echo "CSCRIPT Figlet.vbs /text:[TEXT] /font:[FONT_NAME]"
    WScript.Echo "Where"
    WScript.Echo "[TEXT] - The text to be converted!"
    WScript.Echo "[FONT_NAME] - The name of the font to use!"
End Sub